function q_new = kinematicMotionControl(tf,ts,k,q_current,r_traj)
  % Inputs:
  %  tf         : total simulation time.
  %  ts         : simulation time-step.
  %  k          : current iteration.
  %  q_current  : current configuration of the robot
  % Output: joint-space state of the robot to send to the visualization.

  % Total number of iterations
  Nf = tf/ts;

  % Step 1. - Sample trajectory configuration
  omega = 0.25;
  time = k*ts;
  Dq_max = 0.5;

  % Step 2. - Compute the updated joint velocities - this would be used for
  % a velocity controllable robot
  Dq = 2*pi*omega*Dq_max*cos(2*pi*omega*time) * ones(6,1);

  % Step 3. - Time integration step - this is would be used for a position
  % controllable robot
  q_new = q_current + Dq*ts;

end
